@@ -27,37 +27,16 @@ import (
 // custom no config error
 var ErrNoConfig = errors.New("no config file specified")
 
-func Load(configFile string, migrate bool) *Config {
+func Load(configFile string) *Config {
 	defer log.Trace(time.Now())
 
 	if configFile == "" {
 		return Default(false)
 	}
 
-	configFile = resolveConfigLocation(configFile)
-
-	cfg := parseConfigFile(configFile)
-
-	cfg.toggleSegments()
-
-	// only migrate automatically when the switch isn't set
-	if !migrate && cfg.Version < Version {
-		cfg.BackupAndMigrate()
-	}
-
-	cfg.Source = configFile
-
-	if cfg.Upgrade == nil {
-		cfg.Upgrade = &upgrade.Config{
-			Source:        upgrade.CDN,
-			DisplayNotice: cfg.UpgradeNotice,
-			Auto:          cfg.AutoUpgrade,
-			Interval:      cache.ONEWEEK,
-		}
-	}
-
-	if cfg.Upgrade.Interval.IsEmpty() {
-		cfg.Upgrade.Interval = cache.ONEWEEK
+	cfg, err := Parse(configFile)
+	if err != nil {
+		cfg = Default(true)
 	}
 
 	return cfg
@@ -100,9 +79,11 @@ type hashWriter interface {
 	Write(p []byte) (n int, err error)
 }
 
-func parseConfigFile(configFile string) *Config {
+func Parse(configFile string) (*Config, error) {
 	defer log.Trace(time.Now())
 
+	configFile = resolveConfigLocation(configFile)
+
 	configDSC := DSC()
 	configDSC.Load()
 	configDSC.Add(configFile)
@@ -111,17 +92,17 @@ func parseConfigFile(configFile string) *Config {
 
 	h := fnv.New64a()
 
-	cfg, err := readConfig(configFile, h)
+	cfg, err := read(configFile, h)
 	if err != nil {
 		log.Error(err)
-		return Default(true)
+		return nil, err
 	}
 
 	parentFolder := filepath.Dir(configFile)
 
 	for cfg.Extends != "" {
 		cfg.Extends = resolvePath(cfg.Extends, parentFolder)
-		base, err := readConfig(cfg.Extends, h)
+		base, err := read(cfg.Extends, h)
 		if err != nil {
 			log.Error(err)
 			break
@@ -138,9 +119,28 @@ func parseConfigFile(configFile string) *Config {
 		cfg = base
 	}
 
+	cfg.Source = configFile
 	cfg.hash = h.Sum64()
+	// Migrate segment properties to options for TOML configs
+	// (go-toml/v2 doesn't support custom unmarshalers)
+	cfg.migrateSegmentProperties()
 
-	return cfg
+	cfg.toggleSegments()
+
+	if cfg.Upgrade == nil {
+		cfg.Upgrade = &upgrade.Config{
+			Source:        upgrade.CDN,
+			DisplayNotice: cfg.UpgradeNotice,
+			Auto:          cfg.AutoUpgrade,
+			Interval:      cache.ONEWEEK,
+		}
+	}
+
+	if cfg.Upgrade.Interval.IsEmpty() {
+		cfg.Upgrade.Interval = cache.ONEWEEK
+	}
+
+	return cfg, nil
 }
 
 func resolvePath(configFile, parentFolder string) string {
@@ -161,7 +161,7 @@ func resolvePath(configFile, parentFolder string) string {
 	return filepath.Join(parentFolder, configFile)
 }
 
-func readConfig(configFile string, h hashWriter) (*Config, error) {
+func read(configFile string, h hashWriter) (*Config, error) {
 	defer log.Trace(time.Now())
 
 	if configFile == "" {
